@@ -42,6 +42,7 @@
 #include "glib.h"
 #include "gprintf.h"
 
+#include "galias.h"
 
 struct _GStringChunk
 {
@@ -58,6 +59,17 @@ static GMemChunk *string_mem_chunk = NULL;
 /* Hash Functions.
  */
 
+/**
+ * g_str_equal:
+ * @v1: a key. 
+ * @v2: a key to compare with @v1.
+ * 
+ * Compares two strings and returns %TRUE if they are equal.
+ * It can be passed to g_hash_table_new() as the @key_equal_func
+ * parameter, when using strings as keys in a #GHashTable.
+ *
+ * Returns: %TRUE if the two keys match.
+ */
 gboolean
 g_str_equal (gconstpointer v1,
 	     gconstpointer v2)
@@ -68,12 +80,22 @@ g_str_equal (gconstpointer v1,
   return strcmp (string1, string2) == 0;
 }
 
-/* 31 bit hash function */
+/**
+ * g_str_hash:
+ * @v: a string key.
+ *
+ * Converts a string to a hash value.
+ * It can be passed to g_hash_table_new() as the @hash_func parameter, 
+ * when using strings as keys in a #GHashTable.
+ *
+ * Returns: a hash value corresponding to the key.
+ */
 guint
-g_str_hash (gconstpointer key)
+g_str_hash (gconstpointer v)
 {
-  const char *p = key;
-  guint h = *p;
+  /* 31 bit hash function */
+  const signed char *p = v;
+  guint32 h = *p;
 
   if (h)
     for (p += 1; *p != '\0'; p++)
@@ -515,6 +537,7 @@ g_string_append_len (GString	 *string,
   return g_string_insert_len (string, -1, val, len);
 }
 
+#undef g_string_append_c
 GString*
 g_string_append_c (GString *string,
 		   gchar    c)
@@ -856,3 +879,6 @@ g_string_append_printf (GString *string,
   g_string_append_printf_internal (string, fmt, args);
   va_end (args);
 }
+
+#define __G_STRING_C__
+#include "galiasdef.c"
