@@ -21,6 +21,7 @@
 
 #include "gtypeplugin.h"
 #include "gtypemodule.h"
+#include "gobjectalias.h"
 
 typedef struct _ModuleTypeInfo ModuleTypeInfo;
 typedef struct _ModuleInterfaceInfo ModuleInterfaceInfo;
@@ -130,13 +131,6 @@ g_type_module_get_type (void)
   return type_module_type;
 }
 
-/**
- * g_type_module_set_name
- * @module: a #GTypeModule.
- * @name: a human-readable name to use in error messages.
- * 
- * Sets the name for a #GTypeModule 
- **/
 void
 g_type_module_set_name (GTypeModule  *module,
 			const gchar  *name)
@@ -183,16 +177,6 @@ g_type_module_find_interface_info (GTypeModule *module,
   return NULL;
 }
 
-/**
- * g_type_module_use:
- * @module: a #GTypeModule
- * 
- * Increases the use count of a #GTypeModule by one. If the
- * use count was zero before, the plugin will be loaded.
- *
- * Return Value: %FALSE if the plugin needed to be loaded and
- *               loading the plugin failed.
- **/
 gboolean
 g_type_module_use (GTypeModule *module)
 {
@@ -228,16 +212,6 @@ g_type_module_use (GTypeModule *module)
   return TRUE;
 }
 
-/**
- * g_type_module_unuse:
- * @module: a #GTypeModule
- * 
- * Decreases the use count of a #GTypeModule by one. If the
- * result is zero, the module will be unloaded. (However, the
- * #GTypeModule will not be freed, and types associated with the
- * #GTypeModule are not unregistered. Once a #GTypeModule is 
- * initialized, it must exist forever.)
- **/
 void
 g_type_module_unuse (GTypeModule *module)
 {
@@ -298,29 +272,11 @@ g_type_module_complete_interface_info (GTypePlugin    *plugin,
 				       GInterfaceInfo *info)
 {
   GTypeModule *module = G_TYPE_MODULE (plugin);
-  ModuleInterfaceInfo *module_interface_info = g_type_module_find_interface_info (module, interface_type, instance_type);
+  ModuleInterfaceInfo *module_interface_info = g_type_module_find_interface_info (module, instance_type, interface_type);
 
   *info = module_interface_info->info;
 }
 
-/**
- * g_type_module_register_type:
- * @module:  a #GTypeModule
- * @parent_type:    the type for the parent class
- * @type_name:      name for the type
- * @type_info:      type information structure
- * @flags:          flags field providing details about the type           
- * 
- * Looks up or registers a type that is implemented with a particular
- * type plugin. If a type with name @type_name is already registered,
- * the #GType identifier for the type is returned, otherwise the type
- * is newly registered, and the resulting #GType identifier returned.
- *
- * As long as any instances of the type exist, the type plugin will
- * not be unloaded.
- *
- * Return value: the type ID for the class.
- **/
 GType
 g_type_module_register_type (GTypeModule     *module,
 			     GType            parent_type,
@@ -361,6 +317,9 @@ g_type_module_register_type (GTypeModule     *module,
 		     parent_type_name ? parent_type_name : "(unknown)");
 	  return 0;
 	}
+
+      if (module_type_info->info.value_table)
+	g_free ((GTypeValueTable *) module_type_info->info.value_table);
     }
   else
     {
@@ -381,20 +340,6 @@ g_type_module_register_type (GTypeModule     *module,
   return module_type_info->type;
 }
 
-/**
- * g_type_module_add_interface:
- * @module: a #GTypeModule
- * @instance_type: type to which to add the interface.
- * @interface_type: interface type to add
- * @interface_info: type information structure
- * 
- * Registers an additional interface for a type, whose interface
- * lives in the given type plugin. If the interface was already registered
- * for the type in this plugin, nothing will be done. 
- *
- * As long as any instances of the type exist, the type plugin will
- * not be unloaded.
- **/
 void
 g_type_module_add_interface (GTypeModule          *module,
 			     GType                 instance_type,
@@ -443,3 +388,43 @@ g_type_module_add_interface (GTypeModule          *module,
   module_interface_info->loaded = TRUE;
   module_interface_info->info = *interface_info;
 }
+
+GType
+g_type_module_register_enum (GTypeModule      *module,
+                             const gchar      *name,
+                             const GEnumValue *const_static_values)
+{
+  GTypeInfo enum_type_info = { 0, };
+
+  g_return_val_if_fail (G_IS_TYPE_MODULE (module), 0);
+  g_return_val_if_fail (name != NULL, 0);
+  g_return_val_if_fail (const_static_values != NULL, 0);
+
+  g_enum_complete_type_info (G_TYPE_ENUM,
+                             &enum_type_info, const_static_values);
+
+  return g_type_module_register_type (G_TYPE_MODULE (module),
+                                      G_TYPE_ENUM, name, &enum_type_info, 0);
+}
+
+GType
+g_type_module_register_flags (GTypeModule      *module,
+                             const gchar       *name,
+                             const GFlagsValue *const_static_values)
+{
+  GTypeInfo flags_type_info = { 0, };
+
+  g_return_val_if_fail (G_IS_TYPE_MODULE (module), 0);
+  g_return_val_if_fail (name != NULL, 0);
+  g_return_val_if_fail (const_static_values != NULL, 0);
+
+  g_flags_complete_type_info (G_TYPE_FLAGS,
+                             &flags_type_info, const_static_values);
+
+  return g_type_module_register_type (G_TYPE_MODULE (module),
+                                      G_TYPE_FLAGS, name, &flags_type_info, 0);
+}
+
+
+#define __G_TYPE_MODULE_C__
+#include "gobjectaliasdef.c"
