@@ -9,6 +9,9 @@ int arg_test1_int;
 gchar *arg_test2_string;
 gchar *arg_test3_filename;
 
+gchar *callback_test1_string;
+gboolean callback_test2_int;
+
 gchar **array_test1_array;
 
 gboolean ignore_test1_boolean;
@@ -324,6 +327,78 @@ arg_test3 (void)
   g_option_context_free (context);
 }
 
+static gboolean
+callback_parse1 (const gchar *option_name, const gchar *value,
+		 gpointer data, GError **error)
+{
+	callback_test1_string = g_strdup (value);
+	return TRUE;
+}
+
+void
+callback_test1 (void)
+{
+  GOptionContext *context;
+  gboolean retval;
+  GError *error = NULL;
+  gchar **argv;
+  int argc;
+  GOptionEntry entries [] =
+    { { "test", 0, 0, G_OPTION_ARG_CALLBACK, callback_parse1, NULL, NULL },
+      { NULL } };
+  
+  context = g_option_context_new (NULL);
+  g_option_context_add_main_entries (context, entries, NULL);
+
+  /* Now try parsing */
+  argv = split_string ("program --test foo.txt", &argc);
+  
+  retval = g_option_context_parse (context, &argc, &argv, &error);
+  g_assert (retval);
+
+  g_assert (strcmp (callback_test1_string, "foo.txt") == 0);
+
+  g_free (callback_test1_string);
+  
+  g_strfreev (argv);
+  g_option_context_free (context);
+}
+
+static gboolean
+callback_parse2 (const gchar *option_name, const gchar *value,
+		 gpointer data, GError **error)
+{
+	callback_test2_int++;
+	return TRUE;
+}
+
+void
+callback_test2 (void)
+{
+  GOptionContext *context;
+  gboolean retval;
+  GError *error = NULL;
+  gchar **argv;
+  int argc;
+  GOptionEntry entries [] =
+    { { "test", 0, G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, callback_parse2, NULL, NULL },
+      { NULL } };
+  
+  context = g_option_context_new (NULL);
+  g_option_context_add_main_entries (context, entries, NULL);
+
+  /* Now try parsing */
+  argv = split_string ("program --test --test", &argc);
+  
+  retval = g_option_context_parse (context, &argc, &argv, &error);
+  g_assert (retval);
+
+  g_assert (callback_test2_int == 2);
+  
+  g_strfreev (argv);
+  g_option_context_free (context);
+}
+
 void
 ignore_test1 (void)
 {
@@ -859,6 +934,65 @@ unknown_short_test (void)
   g_option_context_free (context);
 }
 
+/* test that lone dashes are treated as non-options */
+void lonely_dash_test (void)
+{
+  GOptionContext *context;
+  gboolean retval;
+  GError *error = NULL;
+  gchar **argv;
+  int argc;
+
+  context = g_option_context_new (NULL);
+
+  /* Now try parsing */
+  argv = split_string ("program -", &argc);
+
+  retval = g_option_context_parse (context, &argc, &argv, &error);
+
+  g_assert (retval);
+
+  g_assert (argv[1] && strcmp (argv[1], "-") == 0);
+
+  g_strfreev (argv);
+  g_option_context_free (context);
+}
+
+void
+missing_arg_test (void)
+{
+  GOptionContext *context;
+  gboolean retval;
+  GError *error = NULL;
+  gchar **argv;
+  int argc;
+  gchar *arg = NULL;
+  GOptionEntry entries [] =
+    { { "test", 't', 0, G_OPTION_ARG_STRING, &arg, NULL, NULL },
+      { NULL } };
+
+  context = g_option_context_new (NULL);
+  g_option_context_add_main_entries (context, entries, NULL);
+
+  /* Now try parsing */
+  argv = split_string ("program --test", &argc);
+
+  retval = g_option_context_parse (context, &argc, &argv, &error);
+  g_assert (retval == FALSE);
+  g_clear_error (&error);
+
+  g_strfreev (argv);
+
+  /* Try parsing again */
+  argv = split_string ("program --t", &argc);
+
+  retval = g_option_context_parse (context, &argc, &argv, &error);
+  g_assert (retval == FALSE);
+
+  g_strfreev (argv);
+  g_option_context_free (context);
+}
+
 int
 main (int argc, char **argv)
 {
@@ -878,6 +1012,10 @@ main (int argc, char **argv)
   /* Test string arrays */
   array_test1 ();
 
+  /* Test callback args */
+  callback_test1 ();
+  callback_test2 ();
+
   /* Test ignoring options */
   ignore_test1 ();
   ignore_test2 ();
@@ -904,5 +1042,11 @@ main (int argc, char **argv)
   /* test for bug 166609 */
   unknown_short_test ();
 
+  /* test for bug 168008 */
+  lonely_dash_test ();
+
+  /* test for bug 305576 */
+  missing_arg_test ();
+
   return 0;
 }
